package WebService::Mattermost::V4::API::Resource::Schemes;

# ABSTRACT: Wrapped API methods for the schemes API endpoints.

use Moo;

extends 'WebService::Mattermost::V4::API::Resource';

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

WebService::Mattermost::V4::API::Resource::Schemes - Wrapped API methods for the schemes API endpoints.

=head1 VERSION

version 0.31

=head1 DESCRIPTION

Stub for (incomplete) schemes resource integration.

=head1 SEE ALSO

=over 4

=item * L<Official API documentation|https://api.mattermost.com/#tag/schemes>

=back

=head1 AUTHOR

Mike Jones <mike@netsplit.org.uk>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2023 by Mike Jones.

This is free software, licensed under:

  The MIT (X11) License

=cut
